@@ -4,7 +4,7 @@ import re
 import sys
 
 from debmutate.debhelper import get_debhelper_compat_level
-from lintian_brush.fixer import report_result
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 from lintian_brush.rules import update_rules
 
 compat_version = get_debhelper_compat_level()
@@ -13,7 +13,12 @@ if compat_version is None:
 
 
 def drop_explicit_dh_compat(line):
-    if re.match(b'export DH_COMPAT[ \t]*=', line):
+    m = re.match(b'export DH_COMPAT[ \t]*=[ \t]*([0-9]+)', line)
+    if m:
+        fixed_lintian_tag(
+            'source',
+            'declares-possibly-conflicting-debhelper-compat-versions',
+            info='rules=%d compat=%s' % (compat_version, m.group(1)))
         return []
     return line
 
@@ -21,6 +26,4 @@ def drop_explicit_dh_compat(line):
 update_rules(global_line_cb=drop_explicit_dh_compat)
 report_result(
     'Avoid setting debhelper compat version in debian/rules '
-    'and debian/compat.',
-    fixed_lintian_tags=[
-        'declares-possibly-conflicting-debhelper-compat-versions'])
+    'and debian/compat.')
