@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 from lintian_brush.xdg import DesktopEntryEditor
-from lintian_brush.fixer import report_result
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 
 import os
 
@@ -14,15 +14,16 @@ for name in os.listdir('debian'):
             if updater.get('Encoding') == 'UTF-8':
                 del updater.entry['Encoding']
                 paths.append(path)
+                fixed_lintian_tag(
+                    'source', 'desktop-entry-contains-encoding-key',
+                    'XX:YY Encoding')
             # TODO(jelmer): if encoding is non-UTF-8, invoke iconv.
 
 
 if len(paths) == 1:
     report_result(
-        'Remove deprecated Encoding key from desktop file %s.' % paths[0],
-        fixed_lintian_tags=['desktop-entry-contains-encoding-key'])
+        'Remove deprecated Encoding key from desktop file %s.' % paths[0])
 else:
     report_result(
         'Remove deprecated Encoding key from desktop files: %s.' % (
-            ', '.join(sorted(paths))),
-        fixed_lintian_tags=['desktop-entry-contains-encoding-key'])
+            ', '.join(sorted(paths))))
