@@ -1,12 +1,13 @@
 #!/usr/bin/python3
 
-from lintian_brush.control import ControlUpdater
-from lintian_brush.fixer import report_result
+from debmutate.control import ControlEditor
+
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 
 updated_packages = set()
 
 
-with ControlUpdater() as updater:
+with ControlEditor() as updater:
     for binary in updater.binaries:
         package = binary['Package']
         if (not package.startswith('fonts-') and
@@ -18,9 +19,10 @@ with ControlUpdater() as updater:
             continue
         binary['Multi-Arch'] = 'foreign'
         updated_packages.add(package)
+        fixed_lintian_tag(
+            updater.source, 'font-package-not-multi-arch-foreign')
 
 
 report_result(
     'Set Multi-Arch: foreign on package%s %s.' % (
-        's' if len(updated_packages) > 1 else '', ', '.join(updated_packages)),
-    fixed_lintian_tags=['font-package-not-multi-arch-foreign'])
+        's' if len(updated_packages) > 1 else '', ', '.join(updated_packages)))
