@@ -1,9 +1,11 @@
 #!/usr/bin/python3
 
-from lintian_brush.control import ensure_some_version, ControlUpdater
-from lintian_brush.fixer import report_result
 import os
 
+from debmutate.control import ensure_some_version, ControlEditor
+
+from lintian_brush.fixer import report_result, fixed_lintian_tag
+
 needs_lsb_base = set()
 other_service_present = set()
 
@@ -23,14 +25,17 @@ for n in os.listdir('debian'):
 needs_lsb_base -= other_service_present
 
 if needs_lsb_base:
-    with ControlUpdater() as updater:
+    with ControlEditor() as updater:
         for binary in updater.binaries:
             if binary['Package'] not in needs_lsb_base:
                 continue
-            binary['Depends'] = ensure_some_version(
-                binary['Depends'], 'lsb-base')
+            new_depends = ensure_some_version(binary['Depends'], 'lsb-base')
+            if new_depends != binary['Depends']:
+                fixed_lintian_tag(
+                    updater.source, 'init.d-script-needs-depends-on-lsb-base',
+                    'XX (line YY)')
+                binary['Depends'] = new_depends
 
 report_result(
     'Add missing dependency on lsb-base.',
-    fixed_lintian_tags=['init.d-script-needs-depends-on-lsb-base'],
     certainty='possible')
