@@ -1,7 +1,8 @@
 #!/usr/bin/python3
 
-from lintian_brush.control import ControlUpdater
+from debmutate.control import ControlEditor
 from lintian_brush.fixer import (
+    fixed_lintian_tag,
     meets_minimum_certainty,
     report_result,
     trust_package,
@@ -10,7 +11,7 @@ from lintian_brush.upstream_metadata import guess_upstream_metadata_items
 
 current_certainty = None
 
-with ControlUpdater() as updater:
+with ControlEditor() as updater:
     if 'Homepage' not in updater.source:
         for datum in guess_upstream_metadata_items(
                 '.', trust_package=trust_package()):
@@ -21,8 +22,6 @@ with ControlUpdater() as updater:
             if current_certainty != 'certain':
                 updater.source["Homepage"] = datum.value
                 current_certainty = datum.certainty
+                fixed_lintian_tag('source', 'no-homepage-field')
 
-report_result(
-    'Fill in Homepage field.',
-    fixed_lintian_tags=['no-homepage-field'],
-    certainty=current_certainty)
+report_result('Fill in Homepage field.', certainty=current_certainty)
