@@ -3,6 +3,7 @@
 from lintian_brush.fixer import (
     package_is_native,
     report_result,
+    fixed_lintian_tag,
     )
 import os
 import sys
@@ -15,11 +16,12 @@ try:
     os.unlink('debian/upstream/metadata')
 except FileNotFoundError:
     sys.exit(0)
+else:
+    fixed_lintian_tag('source', 'upstream-metadata-in-native-source', ())
 
 if os.listdir('debian/upstream') == []:
     os.rmdir('debian/upstream')
 
 report_result(
     'Remove debian/upstream/metadata in native source package.',
-    fixed_lintian_tags=['upstream-metadata-in-native-source'],
     certainty='certain')
