@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 from debmutate.control import ControlEditor
-from lintian_brush.fixer import report_result
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 from lintian_brush.vcs import canonicalize_vcs_url
 
 
@@ -15,9 +15,10 @@ with ControlEditor() as updater:
         new_value = canonicalize_vcs_url(
             name[len("Vcs-"):], updater.source[name])
         if new_value != updater.source[name]:
+            fixed_lintian_tag(
+                updater.source, 'vcs-field-not-canonical',
+                '%s %s' % (updater.source[name], new_value))
             updater.source[name] = new_value
             fields.add(name)
 
-report_result(
-    "Use canonical URL in " + ', '.join(sorted(fields)) + '.',
-    fixed_lintian_tags=['vcs-field-not-canonical'])
+report_result("Use canonical URL in " + ', '.join(sorted(fields)) + '.')
