@@ -17,9 +17,11 @@
 
 """Automatically fix lintian issues."""
 
+from datetime import datetime
 from debian.changelog import Changelog, Version
 import errno
 import io
+import itertools
 import os
 import re
 import shutil
@@ -28,22 +30,19 @@ import sys
 import tempfile
 import time
 import traceback
-from typing import Optional, List, Sequence, Iterator, Iterable
-import warnings
+from typing import Optional, List, Sequence, Iterator, Iterable, Tuple
 
 from breezy import ui
 
 import breezy.bzr  # noqa: F401
 import breezy.git  # noqa: F401
-from breezy.clean_tree import (
-    iter_deletables,
-    )
 from breezy.commit import NullCommitReporter
 from breezy.errors import NoSuchFile
 from breezy.osutils import is_inside
 from breezy.rename_map import RenameMap
-from breezy.trace import note
+from breezy.trace import note, mutter, warning
 from breezy.transform import revert
+from breezy.tree import Tree
 from breezy.workingtree import WorkingTree
 
 from debian.deb822 import Deb822
@@ -52,7 +51,7 @@ from debian.deb822 import Deb822
 from debmutate.reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 76)
+__version__ = (0, 81)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'confident', 'likely', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
@@ -131,8 +130,8 @@ class NotDebianPackage(Exception):
 class PendingChanges(Exception):
     """The directory has pending changes."""
 
-    def __init__(self, tree):
-        super(PendingChanges, self).__init__(tree.basedir)
+    def __init__(self, tree, subpath=''):
+        super(PendingChanges, self).__init__(tree.abspath(subpath))
 
 
 class FixerResult(object):
@@ -205,7 +204,7 @@ def parse_script_fixer_output(text):
     certainty = None
     patch_name = None
     for line in text.splitlines():
-        # TODO(jelmer): Do this in a slighly less hackish manner
+        # TODO(jelmer): Do this in a slightly less hackish manner
         try:
             (key, value) = line.split(':', 1)
         except ValueError:
@@ -482,8 +481,8 @@ def delete_items(deletables, dry_run: bool = False):
         # Other errors are re-raised.
         if function is not os.remove or excinfo[1].errno != errno.EACCES:
             raise
-        warnings.warn('unable to remove %s' % path)
-    for path, subp in deletables:
+        warning('unable to remove %s', path)
+    for path in deletables:
         if os.path.isdir(path):
             shutil.rmtree(path, onerror=onerror)
         else:
@@ -493,8 +492,7 @@ def delete_items(deletables, dry_run: bool = False):
                 # We handle only permission error here
                 if e.errno != errno.EACCES:
                     raise e
-                warnings.warn(
-                    'unable to remove "{0}": {1}.'.format(path, e.strerror))
+                warning('unable to remove "%s": %s.', path, e.strerror)
 
 
 def get_committer(tree: WorkingTree) -> str:
@@ -531,6 +529,7 @@ def get_committer(tree: WorkingTree) -> str:
 
 def only_changes_last_changelog_block(
         tree: WorkingTree,
+        basis_tree: Tree,
         changelog_path: str,
         changes) -> bool:
     """Check whether the only change in a tree is to the last changelog entry.
@@ -542,18 +541,28 @@ def only_changes_last_changelog_block(
     Returns:
       boolean
     """
-    basis_tree = tree.basis_tree()
     with tree.lock_read(), basis_tree.lock_read():
+        changes_seen = False
         for change in changes:
-            if change.path == ('', ''):
+            if change.path[1] == '':
+                continue
+            if change.path[1] == changelog_path:
+                changes_seen = True
+                continue
+            if (not tree.has_versioned_directories() and
+                    is_inside(change.path[1], changelog_path)):
                 continue
-            if change.path != (changelog_path, changelog_path):
-                return False
-            break
-        else:
             return False
-        new_cl = Changelog(tree.get_file_text(changelog_path))
-        old_cl = Changelog(basis_tree.get_file_text(changelog_path))
+        if not changes_seen:
+            return False
+        try:
+            new_cl = Changelog(tree.get_file_text(changelog_path))
+        except NoSuchFile:
+            return False
+        try:
+            old_cl = Changelog(basis_tree.get_file_text(changelog_path))
+        except NoSuchFile:
+            return True
         if old_cl.distributions != "UNRELEASED":
             return False
         del new_cl._blocks[0]
@@ -561,8 +570,8 @@ def only_changes_last_changelog_block(
         return str(new_cl) == str(old_cl)
 
 
-def reset_tree(local_tree: WorkingTree, dirty_tracker=None,
-               subpath: str = '') -> None:
+def reset_tree(local_tree: WorkingTree, basis_tree: Optional[Tree] = None,
+               subpath: str = '', dirty_tracker=None) -> None:
     """Reset a tree back to its basis tree.
 
     This will leave ignored and detritus files alone.
@@ -574,10 +583,17 @@ def reset_tree(local_tree: WorkingTree, dirty_tracker=None,
     """
     if dirty_tracker and not dirty_tracker.is_dirty():
         return
-    revert(local_tree, local_tree.branch.basis_tree(),
+    if basis_tree is None:
+        basis_tree = local_tree.branch.basis_tree()
+    revert(local_tree, basis_tree,
            [subpath] if subpath not in ('.', '') else None)
-    deletables = list(iter_deletables(
-        local_tree, unknown=True, ignored=False, detritus=False))
+    deletables: List[str] = []
+    # TODO(jelmer): Use basis tree
+    for p in local_tree.extras():
+        if not is_inside(subpath, p):
+            continue
+        if not local_tree.is_ignored(p):
+            deletables.append(local_tree.abspath(p))
     delete_items(deletables)
 
 
@@ -602,25 +618,45 @@ def certainty_sufficient(actual_certainty: str,
     return actual_confidence <= minimum_confidence
 
 
-def check_clean_tree(local_tree: WorkingTree) -> None:
+def check_clean_tree(
+        local_tree: WorkingTree, basis_tree: Tree, subpath: str = '') -> None:
     """Check that a tree is clean and has no pending changes or unknown files.
 
     Args:
       local_tree: The tree to check
+      basis_tree: Tree to check against
+      subpath: Subpath of the tree to check
     Raises:
       PendingChanges: When there are pending changes
     """
     # Just check there are no changes to begin with
-    if local_tree.has_changes():
-        raise PendingChanges(local_tree)
-    if list(local_tree.unknowns()):
-        raise PendingChanges(local_tree)
+    changes = local_tree.iter_changes(
+        basis_tree, include_unchanged=False,
+        require_versioned=False, want_unversioned=True,
+        specific_files=[subpath])
+
+    def relevant(p, t):
+        if not p:
+            return False
+        if not is_inside(subpath, p):
+            return False
+        if t.is_ignored(p):
+            return False
+        if not t.has_versioned_directories() and t.kind(p) == 'directory':
+            return False
+        return True
+
+    if any(change for change in changes if
+           relevant(change.path[0], basis_tree) or
+           relevant(change.path[1], local_tree)):
+        raise PendingChanges(local_tree, subpath)
 
 
-def has_non_debian_changes(changes):
+def has_non_debian_changes(changes, subpath):
     for change in changes:
         for path in change.path:
-            if path and not is_inside('debian', path):
+            if path and not is_inside(
+                    os.path.join(subpath, 'debian'), path):
                 return True
     return False
 
@@ -639,6 +675,53 @@ def _note_changelog_policy(policy, msg):
     _changelog_policy_noted = True
 
 
+class FailedPatchManipulation(Exception):
+
+    def __init__(self, tree, patches_directory, reason):
+        super(FailedPatchManipulation, self).__init__(
+            tree, patches_directory, reason)
+
+
+def _upstream_changes_to_patch(
+        local_tree: WorkingTree,
+        basis_tree: Tree,
+        dirty_tracker,
+        subpath: str, patch_name: str, patch_description: str,
+        timestamp: Optional[datetime] = None) -> Tuple[str, List[str]]:
+    from .patches import (
+        move_upstream_changes_to_patch,
+        read_quilt_patches,
+        tree_patches_directory,
+        PatchSyntax,
+        )
+    # TODO(jelmer): Apply all patches before generating a diff.
+
+    patches_directory = tree_patches_directory(local_tree, subpath)
+    try:
+        quilt_patches = list(read_quilt_patches(local_tree, patches_directory))
+    except PatchSyntax as e:
+        raise FailedPatchManipulation(
+            local_tree, patches_directory,
+            "Unable to parse some patches: %s" % e)
+    if len(quilt_patches) > 0:
+        raise FailedPatchManipulation(
+            local_tree, patches_directory,
+            "Creating patch on top of existing upstream "
+            "patches not supported.")
+
+    mutter('Moving upstream changes to patch %s', patch_name)
+    try:
+        specific_files, patch_name = move_upstream_changes_to_patch(
+            local_tree, basis_tree, subpath, patch_name, patch_description,
+            dirty_tracker, timestamp=timestamp)
+    except FileExistsError as e:
+        raise FailedPatchManipulation(
+            local_tree, patches_directory,
+            'patch path %s already exists\n' % e.args[0])
+
+    return patch_name, specific_files
+
+
 def run_lintian_fixer(local_tree: WorkingTree,
                       fixer: Fixer,
                       committer: Optional[str] = None,
@@ -648,14 +731,18 @@ def run_lintian_fixer(local_tree: WorkingTree,
                       trust_package: bool = False,
                       allow_reformatting: bool = False,
                       dirty_tracker=None,
-                      subpath: str = '.',
+                      subpath: str = '',
                       net_access: bool = True,
                       opinionated: Optional[bool] = None,
-                      diligence: int = 0):
+                      diligence: int = 0,
+                      timestamp: Optional[datetime] = None,
+                      basis_tree: Optional[Tree] = None,
+                      changes_by: str = "lintian-brush"):
     """Run a lintian fixer on a tree.
 
     Args:
       local_tree: WorkingTree object
+      basis_tree: Tree
       fixer: Fixer object to apply
       committer: Optional committer (name and email)
       update_changelog: Whether to add a new entry to the changelog
@@ -674,6 +761,9 @@ def run_lintian_fixer(local_tree: WorkingTree,
     Returns:
       tuple with set of FixerResult, summary of the changes
     """
+    if basis_tree is None:
+        basis_tree = local_tree.basis_tree()
+
     if subpath == '.':
         changelog_path = 'debian/changelog'
     else:
@@ -707,10 +797,13 @@ def run_lintian_fixer(local_tree: WorkingTree,
             opinionated=opinionated,
             diligence=diligence)
     except BaseException:
-        reset_tree(local_tree, dirty_tracker, subpath)
+        reset_tree(local_tree, basis_tree, subpath,
+                   dirty_tracker=dirty_tracker)
         raise
     if not certainty_sufficient(result.certainty, minimum_certainty):
-        reset_tree(local_tree, dirty_tracker, subpath)
+        reset_tree(
+            local_tree, basis_tree, subpath,
+            dirty_tracker=dirty_tracker)
         raise NotCertainEnough(fixer, result.certainty, minimum_certainty)
     specific_files: Optional[List[str]]
     if dirty_tracker:
@@ -728,9 +821,8 @@ def run_lintian_fixer(local_tree: WorkingTree,
             raise NoChanges(fixer, "Script didn't make any changes")
     else:
         local_tree.smart_add([local_tree.abspath(subpath)])
-        specific_files = [subpath] if subpath != '.' else None
+        specific_files = [subpath] if subpath else None
 
-    basis_tree = local_tree.basis_tree()
     if local_tree.supports_setting_file_ids():
         RenameMap.guess_renames(
             basis_tree, local_tree, dry_run=False)
@@ -747,22 +839,21 @@ def run_lintian_fixer(local_tree: WorkingTree,
 
     lines = result.description.splitlines()
     summary = lines[0]
-    details = lines[1:]
+    details = list(itertools.takewhile(lambda line: line, lines[1:]))
 
     # If there are upstream changes in a non-native package, perhaps
     # export them to debian/patches
-    if has_non_debian_changes(changes) and current_version.debian_revision:
-        # TODO(jelmer): Apply all patches before generating a diff.
-        reset_tree(local_tree, dirty_tracker, subpath)
-        raise NoChanges("Creating upstream patches not supported yet")
-
-        from .patches import move_upstream_changes_to_patch
+    if (has_non_debian_changes(changes, subpath) and
+            current_version.debian_revision):
         try:
-            specific_files, patch_name = move_upstream_changes_to_patch(
-                local_tree, subpath, result.patch_name, result.description,
-                dirty_tracker)
-        except FileExistsError as e:
-            raise NoChanges('patch path %s already exists\n' % e.args[0])
+            patch_name, specific_files = _upstream_changes_to_patch(
+                local_tree, basis_tree, dirty_tracker, subpath,
+                result.patch_name or fixer.name,
+                result.description, timestamp=timestamp)
+        except BaseException:
+            reset_tree(local_tree, basis_tree, subpath,
+                       dirty_tracker=dirty_tracker)
+            raise
 
         summary = 'Add patch %s: %s' % (patch_name, summary)
 
@@ -777,7 +868,7 @@ def run_lintian_fixer(local_tree: WorkingTree,
             update_changelog = True
 
     if update_changelog and only_changes_last_changelog_block(
-            local_tree, changelog_path, changes):
+            local_tree, basis_tree, changelog_path, changes):
         # If the script only changed the last entry in the changelog,
         # don't update the changelog
         update_changelog = False
@@ -790,7 +881,7 @@ def run_lintian_fixer(local_tree: WorkingTree,
 
     description = result.description + "\n"
     description += "\n"
-    description += "Changes-By: lintian-brush\n"
+    description += "Changes-By: %s\n" % changes_by
     for tag in result.fixed_lintian_tags:
         description += "Fixes: lintian: %s\n" % tag
         description += (
@@ -805,7 +896,7 @@ def run_lintian_fixer(local_tree: WorkingTree,
         committer=committer,
         specific_files=specific_files)
     result.revision_id = revid
-    # TODO(jelmer): Run sbuild & verify lintian warning is gone?
+    # TODO(jelmer): Support running sbuild & verify lintian warning is gone?
     return result, summary
 
 
@@ -857,7 +948,7 @@ def run_lintian_fixers(local_tree: WorkingTree,
                        trust_package: bool = False,
                        allow_reformatting: bool = False,
                        use_inotify: Optional[bool] = None,
-                       subpath: str = '.',
+                       subpath: str = '',
                        net_access: bool = True,
                        opinionated: Optional[bool] = None,
                        diligence: int = 0):
@@ -888,7 +979,8 @@ def run_lintian_fixers(local_tree: WorkingTree,
         2. dictionary mapping fixer names for fixers that failed to run to the
            error that occurred
     """
-    check_clean_tree(local_tree)
+    basis_tree = local_tree.basis_tree()
+    check_clean_tree(local_tree, basis_tree, subpath)
     fixers = list(fixers)
     dirty_tracker = get_dirty_tracker(
         local_tree, subpath=subpath, use_inotify=use_inotify)
@@ -903,7 +995,8 @@ def run_lintian_fixers(local_tree: WorkingTree,
                 dirty_tracker.mark_clean()
             try:
                 result, summary = run_lintian_fixer(
-                        local_tree, fixer, update_changelog=update_changelog,
+                        local_tree, fixer,
+                        update_changelog=update_changelog,
                         committer=committer, compat_release=compat_release,
                         minimum_certainty=minimum_certainty,
                         trust_package=trust_package,
@@ -911,7 +1004,8 @@ def run_lintian_fixers(local_tree: WorkingTree,
                         dirty_tracker=dirty_tracker,
                         subpath=subpath, net_access=net_access,
                         opinionated=opinionated,
-                        diligence=diligence)
+                        diligence=diligence,
+                        basis_tree=basis_tree)
             except FormattingUnpreservable as e:
                 ret.formatting_unpreservable[fixer.name] = e.path
                 if verbose:
@@ -933,6 +1027,11 @@ def run_lintian_fixers(local_tree: WorkingTree,
                          'certainty (was %r, needed %r). (took: %.2fs)',
                          fixer.name, e.certainty, e.minimum_certainty,
                          time.time() - start)
+            except FailedPatchManipulation as e:
+                if verbose:
+                    note('Unable to manipulate upstream patches: %s',
+                         e.args[2])
+                ret.failed_fixers[fixer.name] = e
             except NoChanges:
                 if verbose:
                     note('Fixer %r made no changes. (took: %.2fs)',
@@ -942,6 +1041,7 @@ def run_lintian_fixers(local_tree: WorkingTree,
                     note('Fixer %r made changes. (took %.2fs)',
                          fixer.name, time.time() - start)
                 ret.success.append((result, summary))
+                basis_tree = local_tree.basis_tree()
     return ret
 
 
