@@ -238,6 +238,14 @@ def apply_multiarch_hints(hints, minimum_certainty='certain'):
     return changes
 
 
+def changes_by_description(changes):
+    by_description = {}
+    for (binary, hint, description, certainty) in changes:
+        by_description.setdefault(description, []).append(
+            binary['Package'])
+    return by_description
+
+
 class MultiArchHintFixer(Fixer):
 
     def __init__(self, hints):
@@ -261,11 +269,15 @@ class MultiArchHintFixer(Fixer):
 
         overall_certainty = min_certainty(
             [certainty for (binary, hint, description, certainty) in changes])
-        overall_description = "Apply multi-arch hints.\n" + "\n".join(
-            ["+ %s: %s" % (binary['Package'], description)
-             for (binary, hint, description, certainty) in changes])
+        by_description = changes_by_description(changes)
+        overall_description = ["Apply multi-arch hints."]
+        for description, binaries in by_description.items():
+            overall_description.append("+ %s: %s" % (
+                ', '.join(sorted(binaries)),
+                description))
         return MultiArchFixerResult(
-            overall_description, certainty=overall_certainty, changes=changes)
+            "\n".join(overall_description),
+            certainty=overall_certainty, changes=changes)
 
 
 APPLIERS = [
@@ -344,7 +356,7 @@ def main(argv=None):
 
     use_inotify = (False if args.disable_inotify else None),
     try:
-        check_clean_tree(wt)
+        check_clean_tree(wt, wt.basis_tree(), subpath)
     except PendingChanges:
         note("%s: Please commit pending changes first.", wt.basedir)
         return 1
@@ -363,7 +375,7 @@ def main(argv=None):
             minimum_certainty=minimum_certainty,
             dirty_tracker=dirty_tracker,
             subpath=subpath, allow_reformatting=allow_reformatting,
-            net_access=True)
+            net_access=True, changes_by="apply-multiarch-hints")
     except NoChanges:
         note('Nothing to do.')
     except NotDebianPackage:
