@@ -74,15 +74,17 @@ class Rule(object):
     def __repr__(self):
         return "<%s(%r)>" % (type(self).__name__, self.target)
 
+    @property
+    def targets(self):
+        return self.target.split(b' ')
+
     def has_target(self, target: bytes, exact: bool = True) -> bool:
-        if not self.target:
-            return False
         if exact:
-            # TODO(jelmer): Handle multiple targets
-            return self.target == target
+            return target in self.targets
         else:
-            # TODO(jelmer): Handle multiple targets
-            return matches_wildcard(target.decode(), self.target.decode())
+            return any(
+                [matches_wildcard(
+                    target.decode(), t.decode()) for t in self.targets])
 
     def rename_target(self, oldname: bytes, newname: bytes) -> bool:
         # TODO(jelmer): Handle multiple targets
@@ -138,7 +140,7 @@ class Rule(object):
         return rest
 
 
-def is_conditional(line):
+def _is_conditional(line):
     line = line.lstrip(b' ')
     return (
         line.startswith(b'ifeq') or
@@ -149,6 +151,17 @@ def is_conditional(line):
         line.startswith(b'-include'))
 
 
+def _is_rule(line):
+    before, sep, after = line.partition(b':')
+    if sep != b':':
+        return False
+    if b'=' in before:
+        return False
+    if after.startswith(b'='):
+        return False
+    return True
+
+
 class Makefile(object):
 
     def __init__(self, contents: Optional[bytes] = None):
@@ -203,12 +216,12 @@ class Makefile(object):
         for line in joinedlines:
             if line.startswith(b'\t') and rule:
                 rule.append_line(line)
-            elif is_conditional(line) or line.lstrip(b' ').startswith(b'#'):
+            elif _is_conditional(line) or line.lstrip(b' ').startswith(b'#'):
                 if rule:
                     rule.append_line(line)
                 else:
                     mf.contents.append(line)
-            elif b':' in line and b' ' not in line.split(b':')[0]:
+            elif _is_rule(line):
                 if rule:
                     mf.contents.extend(rule._finish())
                 precomment = []
