@@ -67,6 +67,12 @@ class FixerTestCase(unittest.TestCase):
         self._tempdir = None
 
     def runTest(self):
+        xfail_path = os.path.join(self._path, 'xfail')
+        if os.path.exists(xfail_path):
+            with open(xfail_path, 'r') as f:
+                reason = f.read()  # noqa: F841
+            unittest.expectedFailure(self)
+            return
         env = dict(os.environ.items())
         cl_path = os.path.join(self._testdir, 'debian/changelog')
         if os.path.exists(cl_path):
@@ -174,6 +180,7 @@ def test_suite():
 
 if __name__ == '__main__':
     import argparse
+    import sys
     parser = argparse.ArgumentParser()
     parser.add_argument(
         '--fixer', type=str, default=None,
@@ -185,7 +192,12 @@ if __name__ == '__main__':
 
     fixers = list(available_lintian_fixers())
     if args.fixer:
-        fixers = select_fixers(fixers, args.fixer, args.exclude)
+        try:
+            fixers = select_fixers(fixers, args.fixer, args.exclude)
+        except KeyError as e:
+            print("Selected fixer %s does not exist." % (e.args[0]),
+                  file=sys.stderr)
+            sys.exit(0)
 
     suite = unittest.TestSuite()
     for fixer in fixers:
