@@ -27,6 +27,7 @@ from lintian_brush.vcs import (
     plausible_url,
     sanitize_url,
     find_public_vcs_url,
+    is_gitlab_site,
     )
 
 
@@ -100,6 +101,12 @@ class FixUpGitUrlTests(TestCase):
             fixup_broken_git_url(
                 'git://anongit.freedesktop.org/git/xorg/lib/libSM'))
 
+    def test_anongit(self):
+        self.assertEqual(
+            'https://anongit.kde.org/kdev-php.git',
+            fixup_broken_git_url(
+                'git://anongit.kde.org/kdev-php.git'))
+
     def test_gnome(self):
         self.assertEqual(
             'https://gitlab.gnome.org/GNOME/alacarte',
@@ -126,6 +133,11 @@ class SanitizeUrlTests(TestCase):
             'https://github.com/jelmer/blah.git',
             sanitize_url('github.com:jelmer/blah'))
 
+    def test_insecure_savannah(self):
+        self.assertEqual(
+            'https://git.savannah.gnu.org/cgit/gforth.git',
+            sanitize_url('http://git.savannah.gnu.org/cgit/gforth.git'))
+
 
 class DetermineBrowserUrlTests(TestCase):
 
@@ -164,6 +176,22 @@ class DetermineBrowserUrlTests(TestCase):
             'https://git.savannah.gnu.org/cgit/rcs.git',
             determine_browser_url(
                 'git', 'git://git.savannah.gnu.org/rcs.git'))
+        self.assertEqual(
+            'https://sourceforge.net/p/shorewall/debian',
+            determine_browser_url(
+                'git', 'git://git.code.sf.net/p/shorewall/debian'))
+        self.assertEqual(
+            'https://sourceforge.net/p/shorewall/debian/ci/foo/tree',
+            determine_browser_url(
+                'git', 'git://git.code.sf.net/p/shorewall/debian -b foo'))
+        self.assertEqual(
+            'https://sourceforge.net/p/shorewall/debian/ci/HEAD/tree/sp',
+            determine_browser_url(
+                'git', 'git://git.code.sf.net/p/shorewall/debian [sp]'))
+        self.assertEqual(
+            'https://sourceforge.net/p/shorewall/debian/ci/foo/tree/sp',
+            determine_browser_url(
+                'git', 'git://git.code.sf.net/p/shorewall/debian -b foo [sp]'))
 
 
 class PlausibleUrlTests(TestCase):
@@ -231,3 +259,15 @@ class FixupRcpStyleUrlTests(TestCase):
             'ssh://git@salsa.debian.org/jelmer/example',
             fixup_rcp_style_git_url(
                 'ssh://git@salsa.debian.org/jelmer/example'))
+
+
+class TestIsGitLabSite(TestCase):
+
+    def test_not_gitlab(self):
+        self.assertFalse(is_gitlab_site('foo.example.com'))
+        self.assertFalse(is_gitlab_site('github.com'))
+        self.assertFalse(is_gitlab_site(None))
+
+    def test_gitlab(self):
+        self.assertTrue(is_gitlab_site('gitlab.somehost.com'))
+        self.assertTrue(is_gitlab_site('salsa.debian.org'))
