@@ -52,11 +52,12 @@ Supported, but unused.
 """
 
 import json
+import operator
 import os
 import re
 import socket
 import urllib.error
-from typing import Optional
+from typing import Optional, Union, Iterable
 from urllib.parse import quote, urlparse, urlunparse, urljoin, parse_qs
 from warnings import warn
 
@@ -122,6 +123,51 @@ class UpstreamDatum(object):
             self.origin)
 
 
+class UpstreamRequirement(object):
+    """Upstream dependency."""
+
+    def __init__(self, stage, kind, name, origin=None):
+        self.stage = stage
+        self.kind = kind
+        self.name = name
+        self.origin = origin
+
+    def __str__(self):
+        return "%s Upstream Requirement (%s): %s" % (
+            self.stage, self.kind, self.name)
+
+    def __repr__(self):
+        return "%s(%r, %r, %r, origin=%r)" % (
+            type(self).__name__, self.stage, self.kind, self.name, self.origin)
+
+    def __eq__(self, other):
+        return (
+            isinstance(other, type(self)) and self.stage == other.stage and
+            self.kind == other.kind and self.name == other.name and
+            self.origin == other.origin)
+
+
+class UpstreamOutput(object):
+    """Upstream output."""
+
+    def __init__(self, kind, name, origin=None):
+        self.kind = kind
+        self.name = name
+        self.origin = origin
+
+    def __str__(self):
+        return "%s: %s" % (self.kind, self.name)
+
+    def __repr__(self):
+        return "%s(%r, %r, origin=%r)" % (
+            type(self).__name__, self.kind, self.name, self.origin)
+
+    def __eq__(self, other):
+        return (
+            isinstance(other, type(self)) and self.kind == other.kind and
+            self.name == other.name and self.origin == other.origin)
+
+
 def _load_json_url(http_url: str, timeout: int = DEFAULT_URLLIB_TIMEOUT):
     headers = {'User-Agent': USER_AGENT, 'Accept': 'application/json'}
     http_contents = urlopen(
@@ -146,6 +192,23 @@ def get_sf_metadata(project):
         raise NoSuchSourceForgeProject(project)
 
 
+class NoSuchRepologyProject(Exception):
+
+    def __init__(self, project):
+        self.project = project
+
+
+def get_repology_metadata(srcname, repo='debian_unstable'):
+    url = ('https://repology.org/tools/project-by?repo=%s&name_type=srcname'
+           '&target_page=api_v1_project&name=%s' % (repo, srcname))
+    try:
+        return _load_json_url(url)
+    except urllib.error.HTTPError as e:
+        if e.status != 404:
+            raise
+        raise NoSuchRepologyProject(srcname)
+
+
 def guess_repo_from_url(url, net_access=False):
     parsed_url = urlparse(url)
     path_elements = parsed_url.path.strip('/').split('/')
@@ -206,6 +269,8 @@ def guess_repo_from_url(url, net_access=False):
         if parsed_url.path.strip('/').count('/') < 1:
             return None
         parts = parsed_url.path.split('/')
+        if 'issues' in parts:
+            parts = parts[:parts.index('issues')]
         if 'tags' in parts:
             parts = parts[:parts.index('tags')]
         if parts[-1] == '-':
@@ -253,7 +318,8 @@ def known_bad_guess(datum):
     return False
 
 
-def filter_bad_guesses(guessed_items):
+def filter_bad_guesses(
+        guessed_items: Iterable[UpstreamDatum]) -> Iterable[UpstreamDatum]:
     return filter(lambda x: not known_bad_guess(x), guessed_items)
 
 
@@ -269,17 +335,6 @@ def update_from_guesses(upstream_metadata, guessed_items):
     return changed
 
 
-def read_python_pkg_info(path):
-    """Get the metadata from a python setup.py file."""
-    from email.parser import Parser
-    from email.message import Message
-    try:
-        with open(os.path.join(path, 'PKG-INFO'), 'r') as f:
-            return Parser().parse(f)
-    except FileNotFoundError:
-        return Message()
-
-
 def guess_from_debian_rules(path, trust_package):
     from ..rules import Makefile
     mf = Makefile.from_path(path)
@@ -318,19 +373,24 @@ def guess_from_debian_watch(path, trust_package):
             url = w.format_url(package=get_package_name)
             if 'mode=git' in w.options:
                 yield UpstreamDatum(
-                    "Repository", sanitize_vcs_url(url), "confident")
+                    "Repository", sanitize_vcs_url(url), "confident",
+                    origin=path)
                 continue
             if url.startswith('https://') or url.startswith('http://'):
                 repo = guess_repo_from_url(url)
                 if repo:
                     yield UpstreamDatum(
-                        "Repository", sanitize_vcs_url(repo), "likely")
+                        "Repository", sanitize_vcs_url(repo), "likely",
+                        origin=path)
                     continue
             m = re.match('https?://sf.net/([^/]+)', url)
             if m:
-                yield UpstreamDatum("Archive", "SourceForge", "certain")
                 yield UpstreamDatum(
-                    "X-SourceForge-Project", m.group(1), "certain")
+                    "Archive", "SourceForge", "certain",
+                    origin=path)
+                yield UpstreamDatum(
+                    "X-SourceForge-Project", m.group(1), "certain",
+                    origin=path)
                 continue
 
 
@@ -371,6 +431,8 @@ def guess_from_python_metadata(pkg_info):
     if payload.strip() and pkg_info.get_content_type() in (None, 'text/plain'):
         yield UpstreamDatum(
             'X-Description', pkg_info.get_payload(), 'possible')
+    for require in pkg_info.get_all('Requires', []):
+        yield UpstreamRequirement('build', 'python-package', require)
 
 
 def guess_from_pkg_info(path, trust_package):
@@ -419,6 +481,15 @@ def guess_from_setup_py(path, trust_package):
         if url_type in ('Bug Tracker', ):
             yield UpstreamDatum(
                 'Bug-Database', url, 'certain')
+    for require in result.get_requires():
+        yield UpstreamRequirement('build', 'python-package', require)
+    for script in (result.scripts or []):
+        yield UpstreamOutput('binary', os.path.basename(script))
+    entry_points = result.entry_points or {}
+    for script in entry_points.get('console_scripts', []):
+        yield UpstreamOutput('binary', script.split('=')[0])
+    for package in result.packages or []:
+        yield UpstreamOutput('python-package', package)
 
 
 def guess_from_package_json(path, trust_package):
@@ -592,6 +663,28 @@ def url_from_git_clone_command(command):
     return None
 
 
+def url_from_fossil_clone_command(command):
+    import shlex
+    argv = shlex.split(command.decode('utf-8', 'replace'))
+    args = [arg for arg in argv if arg.strip()]
+    i = 0
+    while i < len(args):
+        if not args[i].startswith('-'):
+            i += 1
+            continue
+        if '=' in args[i]:
+            del args[i]
+            continue
+        del args[i]
+    try:
+        url = args[2]
+    except IndexError:
+        url = args[0]
+    if plausible_vcs_url(url):
+        return sanitize_vcs_url(url)
+    return None
+
+
 def guess_from_readme(path, trust_package):
     urls = []
     try:
@@ -599,13 +692,17 @@ def guess_from_readme(path, trust_package):
             lines = list(f.readlines())
             for i, line in enumerate(lines):
                 line = line.strip()
-                if line.strip().lstrip(b'$').strip().startswith(b'git clone '):
-                    line = line.strip().lstrip(b'$').strip()
-                    while line.endswith(b'\\'):
-                        line += lines[i+1]
-                        line = line.strip()
+                cmdline = line.strip().lstrip(b'$').strip()
+                if (cmdline.startswith(b'git clone ') or
+                        cmdline.startswith(b'fossil clone ')):
+                    while cmdline.endswith(b'\\'):
+                        cmdline += lines[i+1]
+                        cmdline = cmdline.strip()
                         i += 1
-                    url = url_from_git_clone_command(line)
+                    if cmdline.startswith(b'git clone '):
+                        url = url_from_git_clone_command(cmdline)
+                    elif cmdline.startswith(b'fossil clone '):
+                        url = url_from_fossil_clone_command(cmdline)
                     if url:
                         urls.append(url)
                 project_re = b'([^/]+)/([^/?.()"#>\\s]*[^-/?.()"#>\\s])'
@@ -647,10 +744,9 @@ def guess_from_readme(path, trust_package):
                 for m in re.finditer(
                         b'https://([^/]+)/([^\\s()"#]+)', line):
                     if is_gitlab_site(m.group(1).decode()):
-                        yield UpstreamDatum(
-                            'Repository',
-                            m.group(0).rstrip(b'.').decode().rstrip(),
-                            'possible')
+                        url = m.group(0).rstrip(b'.').decode().rstrip()
+                        repo_url = guess_repo_from_url(url)
+                        yield UpstreamDatum('Repository', repo_url, 'possible')
     except IsADirectoryError:
         pass
 
@@ -735,6 +831,8 @@ def guess_from_meta_yml(path, trust_package):
                 if url:
                     yield UpstreamDatum(
                         'Repository', sanitize_vcs_url(url), 'certain')
+            for require in data.get('requires', []):
+                yield UpstreamRequirement('build', 'perl', require)
 
 
 def guess_from_doap(path, trust_package):
@@ -980,6 +1078,9 @@ def guess_from_cargo(path, trust_package):
             yield UpstreamDatum('Repository', package['repository'], 'certain')
         if 'version' in package:
             yield UpstreamDatum('X-Version', package['version'], 'confident')
+    for name, details in cargo['dependencies'].items():
+        # TODO(jelmer): Look at details['features'], details['version']
+        yield UpstreamRequirement('build', 'cargo-crate', name)
 
 
 def guess_from_pom_xml(path, trust_package=False):
@@ -1128,7 +1229,8 @@ def _get_guessers(path, trust_package=False):
         n for n in os.listdir(path)
         if any([n.startswith(p)
                 for p in ['readme', 'README', 'HACKING', 'CONTRIBUTING']])
-        and os.path.splitext(n)[1] not in ('.html', '.pdf', '.xml')]
+        and os.path.splitext(n)[1] not in ('.html', '.pdf', '.xml')
+        and not n.endswith('~')]
     CANDIDATES.extend([(n, guess_from_readme) for n in readme_filenames])
 
     try:
@@ -1142,17 +1244,19 @@ def _get_guessers(path, trust_package=False):
         CANDIDATES.extend(
             [(p, guess_from_debian_patch) for p in debian_patches])
 
-    yield guess_from_environment()
+    yield 'environment', guess_from_environment()
 
     for relpath, guesser in CANDIDATES:
         abspath = os.path.join(path, relpath)
         if not os.path.exists(abspath):
             continue
-        yield guesser(abspath, trust_package=trust_package)
+        yield relpath, guesser(abspath, trust_package=trust_package)
 
 
-def guess_upstream_metadata_items(path, trust_package=False,
-                                  minimum_certainty=None):
+def guess_upstream_metadata_items(
+        path: str, trust_package: bool = False,
+        minimum_certainty: Optional[str] = None
+        ) -> Iterable[UpstreamDatum]:
     """Guess upstream metadata items, in no particular order.
 
     Args:
@@ -1160,14 +1264,23 @@ def guess_upstream_metadata_items(path, trust_package=False,
       trust: Whether to trust the package contents and i.e. run
       executables in it
     Yields:
-      Tuples with (key, value, certainty)
+      UpstreamDatum
     """
+    for entry in guess_upstream_info(path, trust_package=trust_package):
+        if isinstance(entry, UpstreamDatum):
+            if certainty_sufficient(entry.certainty, minimum_certainty):
+                yield entry
+
+
+def guess_upstream_info(
+        path: str, trust_package: bool = False) -> Iterable[
+            Union[UpstreamDatum, UpstreamRequirement, UpstreamOutput]]:
     guessers = _get_guessers(path, trust_package=trust_package)
-    for guesser in guessers:
-        for datum in guesser:
-            if not certainty_sufficient(datum.certainty, minimum_certainty):
-                continue
-            yield datum
+    for name, guesser in guessers:
+        for entry in guesser:
+            if entry.origin is None:
+                entry.origin = name
+            yield entry
 
 
 def guess_upstream_metadata(
@@ -1187,8 +1300,7 @@ def guess_upstream_metadata(
     update_from_guesses(
         upstream_metadata,
         filter_bad_guesses(
-            guess_upstream_metadata_items(
-                path, trust_package=trust_package)))
+            guess_upstream_metadata_items(path, trust_package=trust_package)))
 
     extend_upstream_metadata(
         upstream_metadata, path, net_access=net_access,
@@ -1271,6 +1383,45 @@ def guess_from_sf(sf_project):
             yield 'Repository', url
 
 
+def guess_from_repology(repology_project):
+    try:
+        metadata = get_repology_metadata(repology_project)
+    except socket.timeout:
+        warn('timeout contacting repology, ignoring: %s' % repology_project)
+        return
+
+    fields = {}
+
+    def _add_field(name, value, add):
+        fields.setdefault(name, {})
+        fields[name].setdefault(value, 0)
+        fields[name][value] += add
+
+    for entry in metadata:
+        if entry.get('status') == 'outdated':
+            score = 1
+        else:
+            score = 10
+
+        if 'www' in entry:
+            for www in entry['www']:
+                _add_field('Homepage', www, score)
+
+        if 'licenses' in entry:
+            for license in entry['licenses']:
+                _add_field('X-License', license, score)
+
+        if 'summary' in entry:
+            _add_field('X-Summary', entry['summary'], score)
+
+        if 'downloads' in entry:
+            for download in entry['downloads']:
+                _add_field('X-Download', download, score)
+
+    for field, scores in fields.items():
+        yield field, max(scores, key=operator.itemgetter(1))
+
+
 def extend_from_external_guesser(
         upstream_metadata, guesser_certainty, guesser_fields, guesser):
     if not _possible_fields_missing(
@@ -1283,6 +1434,21 @@ def extend_from_external_guesser(
          for (key, value) in guesser])
 
 
+def extend_from_repology(upstream_metadata, minimum_certainty, source_package):
+    # The set of fields that sf can possibly provide:
+    repology_fields = ['Homepage', 'X-License', 'X-Summary', 'X-Download']
+    certainty = 'confident'
+
+    if certainty_sufficient(certainty, minimum_certainty):
+        # Don't bother talking to repology if we're not
+        # speculating.
+        return
+
+    return extend_from_external_guesser(
+        upstream_metadata, certainty, repology_fields,
+        guess_from_repology(source_package))
+
+
 def extend_from_sf(upstream_metadata, sf_project):
     # The set of fields that sf can possibly provide:
     sf_fields = ['Homepage', 'Name', 'Repository']
@@ -1703,6 +1869,7 @@ def extend_upstream_metadata(upstream_metadata, path, minimum_certainty=None,
         else:
             extend_from_lp(upstream_metadata, minimum_certainty, package)
             extend_from_aur(upstream_metadata, minimum_certainty, package)
+            extend_from_repology(upstream_metadata, minimum_certainty, package)
     pecl_url = upstream_metadata.get('X-Pecl-URL')
     if net_access and pecl_url:
         extend_from_pecl(upstream_metadata, pecl_url.value, pecl_url.certainty)
@@ -1750,7 +1917,7 @@ def _version_in_tags(version, tag_names):
     return False
 
 
-def probe_upstream_branch_url(url, version=None):
+def probe_upstream_branch_url(url: str, version=None):
     parsed = urlparse(url)
     if parsed.scheme in ('git+ssh', 'ssh', 'bzr+ssh'):
         # Let's not probe anything possibly non-public.
