@@ -24,6 +24,74 @@ from ruamel.yaml import YAML
 from typing import List
 
 
+class MultiYamlUpdater(object):
+
+    def __init__(self, path: str, remove_empty: bool = False):
+        self.yaml = YAML()
+        self.path = path
+        self.remove_empty = remove_empty
+        self._preamble: List[str] = []
+        self._dirpath = os.path.dirname(path)
+        self._force_rewrite = False
+
+    def __getitem__(self, i):
+        return self._code[i]
+
+    def __setitem__(self, i, val):
+        self._code[i] = val
+
+    def __iter__(self):
+        for m in self._code:
+            yield m
+
+    def __delitem__(self, i):
+        del self._code[i]
+
+    def __len__(self):
+        return len(self._code)
+
+    def __enter__(self):
+        try:
+            with open(self.path, 'r') as f:
+                inp = list(f)
+        except FileNotFoundError:
+            self._orig = {}
+            self._orig_text = ''
+        else:
+            for line in inp:
+                if line != '\n' and not line.startswith('#'):
+                    break
+                self._preamble.append(line)
+            self._orig_text = ''.join(inp)
+            self._orig = list(self.yaml.load_all(self._orig_text))
+        self._code = self._orig.copy()
+        return self
+
+    def _get_code(self):
+        return self._code
+
+    def _set_code(self, v):
+        self._code = v
+
+    code = property(_get_code, _set_code)
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        if not exc_type:
+            if not self._code and self.remove_empty:
+                if os.path.exists(self.path):
+                    os.unlink(self.path)
+                    if self._dirpath and not os.listdir(self._dirpath):
+                        os.rmdir(self._dirpath)
+            else:
+                if self._force_rewrite or self._code != self._orig:
+                    if not os.path.exists(self._dirpath) and self._dirpath:
+                        os.mkdir(self._dirpath)
+                    with open(self.path, 'w') as f:
+                        f.writelines(self._preamble)
+                        self.yaml.dump_all(self._code, f)
+        return False
+
+
 class YamlUpdater(object):
 
     def __init__(
@@ -82,19 +150,21 @@ class YamlUpdater(object):
         for k, v in self._orig.items():
             if k not in self._code and not is_one_line(k, v):
                 return False
+            if ':' in k:
+                return False
         return True
 
     def _update_lines(self, lines, f):
         for line in self._directives:
             f.write(line)
-        if ''.join(lines).startswith('{'):
+        if ''.join(lines[len(self._directives):]).startswith('{'):
             _update_json_lines(
-                self._directives, self._orig, self._code,
-                lines, f)
+                self._orig, self._code,
+                lines[len(self._directives):], f)
         else:
             _update_yaml_lines(
-                self.yaml, self._directives, self._orig, self._code,
-                lines, f)
+                self.yaml, self._orig, self._code,
+                lines[len(self._directives):], f)
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         if not exc_type:
@@ -147,7 +217,7 @@ def update_ordered_dict(code, changed, key=None):
         code[k] = v
 
 
-def _update_json_lines(directives, orig, code, lines, f):
+def _update_json_lines(orig, code, lines, f):
     indent = 0
     for c in lines[1][0:]:
         if c != ' ':
@@ -157,11 +227,11 @@ def _update_json_lines(directives, orig, code, lines, f):
     f.write('\n')
 
 
-def _update_yaml_lines(yaml, directives, orig, code, lines, f):
+def _update_yaml_lines(yaml, orig, code, lines, f):
     os = list(orig.keys())
     cs = list(code.keys())
     o = 0
-    for line in lines[len(directives):]:
+    for line in lines:
         try:
             key = os[o]
         except IndexError:
